/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: spell_tab.h,v 1.20 2003/11/19 13:19:13 bowkenken Exp $
*****************************************************************/

#ifndef	SPELL_TAB_H
#define	SPELL_TAB_H

#include	"menu.h"
#include	"spell_prot.h"

menu_t	ls_menu_spell[] = {
	{
		"/Spell",
		"<Branch>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] */
	{
		"/Spell/MAG",
		"<Branch>",
		'M',
		"",
		N_MSG_MAG, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] ¾ */
	{
		"/Spell/MAG/Title Misc",
		"<Title>",
		'\0',
		"",
		N_MSG_MAG_MISC, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/LIGHT",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_LIGHT, "",
		cb_menu_spell, (void *)SPELL_KIND_LIGHT,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DARKNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DARKNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_DARKNESS,
		FLG_NULL,
	},

	{
		"/Spell/MAG/TELEPORT_PARTY",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_TELEPORT_PARTY, "",
		cb_menu_spell, (void *)SPELL_KIND_TELEPORT_PARTY,
		FLG_NULL,
	},

	{
		"/Spell/MAG/TELEPORT",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_TELEPORT, "",
		cb_menu_spell, (void *)SPELL_KIND_TELEPORT,
		FLG_NULL,
	},

	{
		"/Spell/MAG/RECALL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RECALL, "",
		cb_menu_spell, (void *)SPELL_KIND_RECALL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/KNOCK",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_KNOCK, "",
		cb_menu_spell, (void *)SPELL_KIND_KNOCK,
		FLG_NULL,
	},

	{
		"/Spell/MAG/LOCK",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_LOCK, "",
		cb_menu_spell, (void *)SPELL_KIND_LOCK,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DISARM_TRAP",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DISARM_TRAP, "",
		cb_menu_spell, (void *)SPELL_KIND_DISARM_TRAP,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DISPEL_MAGIC",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DISPEL_MAGIC, "",
		cb_menu_spell, (void *)SPELL_KIND_DISPEL_MAGIC,
		FLG_NULL,
	},

	{
		"/Spell/MAG/MIRROR_IMAGE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_MIRROR_IMAGE, "",
		cb_menu_spell, (void *)SPELL_KIND_MIRROR_IMAGE,
		FLG_NULL,
	},

	{
		"/Spell/MAG/ANIMATE_OBJECTS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_ANIMATE_OBJECTS, "",
		cb_menu_spell, (void *)SPELL_KIND_ANIMATE_OBJECTS,
		FLG_NULL,
	},

	{
		"/Spell/MAG/SHELTER",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SHELTER, "",
		cb_menu_spell, (void *)SPELL_KIND_SHELTER,
		FLG_NULL,
	},

	{
		"/Spell/MAG/CREATE_FOOD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CREATE_FOOD, "",
		cb_menu_spell, (void *)SPELL_KIND_CREATE_FOOD,
		FLG_NULL,
	},

	{
		"/Spell/MAG/CREATE_UNDEAD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CREATE_UNDEAD, "",
		cb_menu_spell, (void *)SPELL_KIND_CREATE_UNDEAD,
		FLG_NULL,
	},

	{
		"/Spell/MAG/NO_LEARN Misc",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] õ */
	{
		"/Spell/MAG/Title Detect",
		"<Title>",
		'\0',
		"",
		N_MSG_MAG_DETECT, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/IDENTIFY_ITEM",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_IDENTIFY_ITEM, "",
		cb_menu_spell, (void *)SPELL_KIND_IDENTIFY_ITEM,
		FLG_NULL,
	},

	{
		"/Spell/MAG/SEARCHING",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SEARCHING, "",
		cb_menu_spell, (void *)SPELL_KIND_SEARCHING,
		FLG_NULL,
	},

	{
		"/Spell/MAG/ANALYZE_DWEOMER",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_ANALYZE_DWEOMER, "",
		cb_menu_spell, (void *)SPELL_KIND_ANALYZE_DWEOMER,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DETECT_MAGIC",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DETECT_MAGIC, "",
		cb_menu_spell, (void *)SPELL_KIND_DETECT_MAGIC,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DETECT_ITEM",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DETECT_ITEM, "",
		cb_menu_spell, (void *)SPELL_KIND_DETECT_ITEM,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DETECT_DOORS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DETECT_DOORS, "",
		cb_menu_spell, (void *)SPELL_KIND_DETECT_DOORS,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DETECT_TRAPS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DETECT_TRAPS, "",
		cb_menu_spell, (void *)SPELL_KIND_DETECT_TRAPS,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DETECT_MONSTER",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DETECT_MONSTER, "",
		cb_menu_spell, (void *)SPELL_KIND_DETECT_MONSTER,
		FLG_NULL,
	},

	{
		"/Spell/MAG/SENSE_INVISIBLE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SENSE_INVISIBLE, "",
		cb_menu_spell, (void *)SPELL_KIND_SENSE_INVISIBLE,
		FLG_NULL,
	},

	{
		"/Spell/MAG/NO_LEARN Detect",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] ƥѲ */
	{
		"/Spell/MAG/Title Change status",
		"<Title>",
		'\0',
		"",
		N_MSG_MAG_CHANGE_STAT, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/FLY",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_FLY, "",
		cb_menu_spell, (void *)SPELL_KIND_FLY,
		FLG_NULL,
	},

	{
		"/Spell/MAG/FEATHER_FALL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_FEATHER_FALL, "",
		cb_menu_spell, (void *)SPELL_KIND_FEATHER_FALL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/VANISH",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_VANISH, "",
		cb_menu_spell, (void *)SPELL_KIND_VANISH,
		FLG_NULL,
	},

	{
		"/Spell/MAG/DARKVISION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DARKVISION, "",
		cb_menu_spell, (void *)SPELL_KIND_DARKVISION,
		FLG_NULL,
	},

	{
		"/Spell/MAG/PASSWALL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_PASSWALL, "",
		cb_menu_spell, (void *)SPELL_KIND_PASSWALL,
		FLG_NULL,
	},
/* [ˡ] üե饰Ѳ */
	{
		"/Spell/MAG/POLYMORPH_OTHER",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_POLYMORPH_OTHER, "",
		cb_menu_spell, (void *)SPELL_KIND_POLYMORPH_OTHER,
		FLG_NULL,
	},

	{
		"/Spell/MAG/POLYMORPH_SELF",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_POLYMORPH_SELF, "",
		cb_menu_spell, (void *)SPELL_KIND_POLYMORPH_SELF,
		FLG_NULL,
	},

	{
		"/Spell/MAG/STEALTH",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_STEALTH, "",
		cb_menu_spell, (void *)SPELL_KIND_STEALTH,
		FLG_NULL,
	},

	{
		"/Spell/MAG/NO_LEARN Change status",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/MAG/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ʈˡ] */
	{
		"/Spell/SOR",
		"<Branch>",
		'O',
		"",
		N_MSG_SOR, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ʈˡ]  */
	{
		"/Spell/SOR/Title Attack",
		"<Title>",
		'\0',
		"",
		N_MSG_SOR_ATTACK, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/MAGIC_MISSILE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_MAGIC_MISSILE, "",
		cb_menu_spell, (void *)SPELL_KIND_MAGIC_MISSILE,
		FLG_NULL,
	},

	{
		"/Spell/SOR/FIRE_BALL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_FIRE_BALL, "",
		cb_menu_spell, (void *)SPELL_KIND_FIRE_BALL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/ICE_BLIZZARD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_ICE_BLIZZARD, "",
		cb_menu_spell, (void *)SPELL_KIND_ICE_BLIZZARD,
		FLG_NULL,
	},

	{
		"/Spell/SOR/ACID_RAIN",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_ACID_RAIN, "",
		cb_menu_spell, (void *)SPELL_KIND_ACID_RAIN,
		FLG_NULL,
	},

	{
		"/Spell/SOR/MIND_STORM",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_MIND_STORM, "",
		cb_menu_spell, (void *)SPELL_KIND_MIND_STORM,
		FLG_NULL,
	},

	{
		"/Spell/SOR/LIGHTNING_BOLT",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_LIGHTNING_BOLT, "",
		cb_menu_spell, (void *)SPELL_KIND_LIGHTNING_BOLT,
		FLG_NULL,
	},

	{
		"/Spell/SOR/POISON_CLOUD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_POISON_CLOUD, "",
		cb_menu_spell, (void *)SPELL_KIND_POISON_CLOUD,
		FLG_NULL,
	},

	{
		"/Spell/SOR/DEATH_SPELL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DEATH_SPELL, "",
		cb_menu_spell, (void *)SPELL_KIND_DEATH_SPELL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/NO_LEARN Attack",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ʈˡ] ɸ */
	{
		"/Spell/SOR/Title Defense",
		"<Title>",
		'\0',
		"",
		N_MSG_SOR_DEFENSE, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/MAGIC_SHIELD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_MAGIC_SHIELD, "",
		cb_menu_spell, (void *)SPELL_KIND_MAGIC_SHIELD,
		FLG_NULL,
	},

	{
		"/Spell/SOR/MAGE_ARMOR",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_MAGE_ARMOR, "",
		cb_menu_spell, (void *)SPELL_KIND_MAGE_ARMOR,
		FLG_NULL,
	},

	{
		"/Spell/SOR/STONESKIN",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_STONESKIN, "",
		cb_menu_spell, (void *)SPELL_KIND_STONESKIN,
		FLG_NULL,
	},

	{
		"/Spell/SOR/IRON_BODY",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_IRON_BODY, "",
		cb_menu_spell, (void *)SPELL_KIND_IRON_BODY,
		FLG_NULL,
	},

	{
		"/Spell/SOR/SPELL_RESISTANCE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SPELL_RESISTANCE, "",
		cb_menu_spell, (void *)SPELL_KIND_SPELL_RESISTANCE,
		FLG_NULL,
	},

	{
		"/Spell/SOR/COUNTER_MAGIC",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_COUNTER_MAGIC, "",
		cb_menu_spell, (void *)SPELL_KIND_COUNTER_MAGIC,
		FLG_NULL,
	},

	{
		"/Spell/SOR/NO_LEARN Defense",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ʈˡ] ơ۾ */
	{
		"/Spell/SOR/Title Weaken status",
		"<Title>",
		'\0',
		"",
		N_MSG_SOR_WEAKEN_STAT, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/STONE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_STONE, "",
		cb_menu_spell, (void *)SPELL_KIND_STONE,
		FLG_NULL,
	},

	{
		"/Spell/SOR/PARALYZE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_PARALYZE, "",
		cb_menu_spell, (void *)SPELL_KIND_PARALYZE,
		FLG_NULL,
	},

	{
		"/Spell/SOR/POISON",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_POISON, "",
		cb_menu_spell, (void *)SPELL_KIND_POISON,
		FLG_NULL,
	},

	{
		"/Spell/SOR/CONFUSION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CONFUSION, "",
		cb_menu_spell, (void *)SPELL_KIND_CONFUSION,
		FLG_NULL,
	},

	{
		"/Spell/SOR/BLINDNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_BLINDNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_BLINDNESS,
		FLG_NULL,
	},

	{
		"/Spell/SOR/SLEEP",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SLEEP, "",
		cb_menu_spell, (void *)SPELL_KIND_SLEEP,
		FLG_NULL,
	},

	{
		"/Spell/SOR/SILENCE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SILENCE, "",
		cb_menu_spell, (void *)SPELL_KIND_SILENCE,
		FLG_NULL,
	},

	{
		"/Spell/SOR/FEAR",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_FEAR, "",
		cb_menu_spell, (void *)SPELL_KIND_FEAR,
		FLG_NULL,
	},

	{
		"/Spell/SOR/HALLUCINATION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_HALLUCINATION, "",
		cb_menu_spell, (void *)SPELL_KIND_HALLUCINATION,
		FLG_NULL,
	},

	{
		"/Spell/SOR/CHARM",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CHARM, "",
		cb_menu_spell, (void *)SPELL_KIND_CHARM,
		FLG_NULL,
	},

	{
		"/Spell/SOR/NO_LEARN Weaken status",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SOR/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] */
	{
		"/Spell/ENC",
		"<Branch>",
		'E',
		"",
		N_MSG_ENC, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] ӥƥ */
	{
		"/Spell/ENC/Title Strengthen ability",
		"<Title>",
		'\0',
		"",
		N_MSG_ENC_STRENGTHEN_ABILITY, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/SHARPNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SHARPNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_SHARPNESS,
		FLG_NULL,
	},

	{
		"/Spell/ENC/STRENGTH",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_STRENGTH, "",
		cb_menu_spell, (void *)SPELL_KIND_STRENGTH,
		FLG_NULL,
	},

	{
		"/Spell/ENC/QUICKNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_QUICKNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_QUICKNESS,
		FLG_NULL,
	},

	{
		"/Spell/ENC/WISE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_WISE, "",
		cb_menu_spell, (void *)SPELL_KIND_WISE,
		FLG_NULL,
	},

	{
		"/Spell/ENC/BRAINY",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_BRAINY, "",
		cb_menu_spell, (void *)SPELL_KIND_BRAINY,
		FLG_NULL,
	},

	{
		"/Spell/ENC/ATTRACTIVE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_ATTRACTIVE, "",
		cb_menu_spell, (void *)SPELL_KIND_ATTRACTIVE,
		FLG_NULL,
	},

	{
		"/Spell/ENC/NO_LEARN Strengthen ability",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ]  */
	{
		"/Spell/ENC/Title Strengthen misc",
		"<Title>",
		'\0',
		"",
		N_MSG_ENC_STRENGTHEN_MISC, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/POWER_UP_HP",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_POWER_UP_HP, "",
		cb_menu_spell, (void *)SPELL_KIND_POWER_UP_HP,
		FLG_NULL,
	},
/* [ˡ]  */
	{
		"/Spell/ENC/HASTE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_HASTE, "",
		cb_menu_spell, (void *)SPELL_KIND_HASTE,
		FLG_NULL,
	},

	{
		"/Spell/ENC/NO_LEARN Strengthen misc",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] ӥƥ */
	{
		"/Spell/ENC/Title Weaken ability",
		"<Title>",
		'\0',
		"",
		N_MSG_ENC_WEAKEN_ABILITY, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/DULLNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DULLNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_DULLNESS,
		FLG_NULL,
	},

	{
		"/Spell/ENC/WEAKNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_WEAKNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_WEAKNESS,
		FLG_NULL,
	},

	{
		"/Spell/ENC/SLOWNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SLOWNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_SLOWNESS,
		FLG_NULL,
	},

	{
		"/Spell/ENC/FOOLISH",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_FOOLISH, "",
		cb_menu_spell, (void *)SPELL_KIND_FOOLISH,
		FLG_NULL,
	},

	{
		"/Spell/ENC/BRAINLESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_BRAINLESS, "",
		cb_menu_spell, (void *)SPELL_KIND_BRAINLESS,
		FLG_NULL,
	},

	{
		"/Spell/ENC/UNATTRACTIVE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_UNATTRACTIVE, "",
		cb_menu_spell, (void *)SPELL_KIND_UNATTRACTIVE,
		FLG_NULL,
	},

	{
		"/Spell/ENC/NO_LEARN Weaken ability",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ]  */
	{
		"/Spell/ENC/Title Weaken misc",
		"<Title>",
		'\0',
		"",
		N_MSG_ENC_WEAKEN_MISC, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/ENERGY_DRAIN",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_ENERGY_DRAIN, "",
		cb_menu_spell, (void *)SPELL_KIND_ENERGY_DRAIN,
		FLG_NULL,
	},
/* [ˡ]  */
	{
		"/Spell/ENC/SLOW",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SLOW, "",
		cb_menu_spell, (void *)SPELL_KIND_SLOW,
		FLG_NULL,
	},

	{
		"/Spell/ENC/HUNGER",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_HUNGER, "",
		cb_menu_spell, (void *)SPELL_KIND_HUNGER,
		FLG_NULL,
	},

	{
		"/Spell/ENC/CANCELLATION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CANCELLATION, "",
		cb_menu_spell, (void *)SPELL_KIND_CANCELLATION,
		FLG_NULL,
	},

	{
		"/Spell/ENC/NO_LEARN Weaken misc",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/ENC/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ] */
	{
		"/Spell/SUM",
		"<Branch>",
		'U',
		"",
		N_MSG_SUM, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ]  */
	{
		"/Spell/SUM/Title Summon",
		"<Title>",
		'\0',
		"",
		N_MSG_SUM_SUMMON, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SUM/SUMMON_MONSTER",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SUMMON_MONSTER, "",
		cb_menu_spell, (void *)SPELL_KIND_SUMMON_MONSTER,
		FLG_NULL,
	},

	{
		"/Spell/SUM/DISMISSAL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DISMISSAL, "",
		cb_menu_spell, (void *)SPELL_KIND_DISMISSAL,
		FLG_NULL,
	},

	{
		"/Spell/SUM/NO_LEARN Summon",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/SUM/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ηʸ] */
	{
		"/Spell/PRI",
		"<Branch>",
		'P',
		"",
		N_MSG_PRI, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ηʸ]  */
	{
		"/Spell/PRI/Title Cure",
		"<Title>",
		'\0',
		"",
		N_MSG_PRI_CURE, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_HP_LIGHT",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_HP_LIGHT, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_HP_LIGHT,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_HP_MODERATE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_HP_MODERATE, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_HP_MODERATE,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_HP_SERIOUS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_HP_SERIOUS, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_HP_SERIOUS,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_HP_MAX",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_HP_MAX, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_HP_MAX,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_MP",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_MP, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_MP,
		FLG_NULL,
	},

	{
		"/Spell/PRI/TRANSFER_MP",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_TRANSFER_MP, "",
		cb_menu_spell, (void *)SPELL_KIND_TRANSFER_MP,
		FLG_NULL,
	},

	{
		"/Spell/PRI/REGENERATION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_REGENERATION, "",
		cb_menu_spell, (void *)SPELL_KIND_REGENERATION,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESTORE_EXPERIENCE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESTORE_EXPERIENCE, "",
		cb_menu_spell, (void *)SPELL_KIND_RESTORE_EXPERIENCE,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESURRECTION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESURRECTION, "",
		cb_menu_spell, (void *)SPELL_KIND_RESURRECTION,
		FLG_NULL,
	},

	{
		"/Spell/PRI/HEAL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_HEAL, "",
		cb_menu_spell, (void *)SPELL_KIND_HEAL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/NO_LEARN Cure",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ηʸ] ֲ */
	{
		"/Spell/PRI/Title Cure status",
		"<Title>",
		'\0',
		"",
		N_MSG_PRI_CURE_STAT, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_STATUS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_STATUS, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_STATUS,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_STONE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_STONE, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_STONE,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_PARALYZE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_PARALYZE, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_PARALYZE,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_BLINDNESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_BLINDNESS, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_BLINDNESS,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_POISON",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_POISON, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_POISON,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_CONFUSION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_CONFUSION, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_CONFUSION,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_SILENCE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_SILENCE, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_SILENCE,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_SLEEP",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_SLEEP, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_SLEEP,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_FEAR",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_FEAR, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_FEAR,
		FLG_NULL,
	},

	{
		"/Spell/PRI/CURE_CHARM",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CURE_CHARM, "",
		cb_menu_spell, (void *)SPELL_KIND_CURE_CHARM,
		FLG_NULL,
	},

	{
		"/Spell/PRI/NO_LEARN Cure status",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ηʸ]  */
	{
		"/Spell/PRI/Title Resist",
		"<Title>",
		'\0',
		"",
		N_MSG_PRI_RESIST, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/PROTECTION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_PROTECTION, "",
		cb_menu_spell, (void *)SPELL_KIND_PROTECTION,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_PHYSICAL",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_PHYSICAL, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_PHYSICAL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_HEAT",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_HEAT, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_HEAT,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_COLD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_COLD, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_COLD,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_ACID",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_ACID, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_ACID,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_MIND",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_MIND, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_MIND,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_ELECTRICITY",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_ELECTRICITY, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_ELECTRICITY,
		FLG_NULL,
	},

	{
		"/Spell/PRI/RESIST_POISON",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_RESIST_POISON, "",
		cb_menu_spell, (void *)SPELL_KIND_RESIST_POISON,
		FLG_NULL,
	},

	{
		"/Spell/PRI/NO_LEARN Resist",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ηʸ]  */
	{
		"/Spell/PRI/Title Holy",
		"<Title>",
		'\0',
		"",
		N_MSG_PRI_HOLY, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/BLESS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_BLESS, "",
		cb_menu_spell, (void *)SPELL_KIND_BLESS,
		FLG_NULL,
	},

	{
		"/Spell/PRI/REMOVE_CURSE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_REMOVE_CURSE, "",
		cb_menu_spell, (void *)SPELL_KIND_REMOVE_CURSE,
		FLG_NULL,
	},

	{
		"/Spell/PRI/DISPEL_UNDEAD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_DISPEL_UNDEAD, "",
		cb_menu_spell, (void *)SPELL_KIND_DISPEL_UNDEAD,
		FLG_NULL,
	},

	{
		"/Spell/PRI/SANCTUARY",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SANCTUARY, "",
		cb_menu_spell, (void *)SPELL_KIND_SANCTUARY,
		FLG_NULL,
	},

	{
		"/Spell/PRI/WISH",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_WISH, "",
		cb_menu_spell, (void *)SPELL_KIND_WISH,
		FLG_NULL,
	},

	{
		"/Spell/PRI/NO_LEARN Holy",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/PRI/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [ˡ]  */
	{
		"/Spell/SHA",
		"<Branch>",
		'H',
		"",
		N_MSG_SHA, "",
		NULL, NULL,
		FLG_NULL,
	},
/* []  */
	{
		"/Spell/BAR",
		"<Branch>",
		'B',
		"",
		N_MSG_BAR, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ǧ] */
	{
		"/Spell/NIN",
		"<Branch>",
		'N',
		"",
		N_MSG_NIN, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ǧ] ŷϰ */
	{
		"/Spell/NIN/Title Disaster",
		"<Title>",
		'\0',
		"",
		N_MSG_NIN_DISASTER, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/NIN/TYPHOON",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_TYPHOON, "",
		cb_menu_spell, (void *)SPELL_KIND_TYPHOON,
		FLG_NULL,
	},

	{
		"/Spell/NIN/CONFLAGRATION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_CONFLAGRATION, "",
		cb_menu_spell, (void *)SPELL_KIND_CONFLAGRATION,
		FLG_NULL,
	},

	{
		"/Spell/NIN/EARTHQUAKE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_EARTHQUAKE, "",
		cb_menu_spell, (void *)SPELL_KIND_EARTHQUAKE,
		FLG_NULL,
	},

	{
		"/Spell/NIN/THUNDERCLOUD",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_THUNDERCLOUD, "",
		cb_menu_spell, (void *)SPELL_KIND_THUNDERCLOUD,
		FLG_NULL,
	},

	{
		"/Spell/NIN/INUNDATION",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_INUNDATION, "",
		cb_menu_spell, (void *)SPELL_KIND_INUNDATION,
		FLG_NULL,
	},

	{
		"/Spell/NIN/NO_LEARN Disaster",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/NIN/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/* [Ǧ]  */
	{
		"/Spell/NIN/Title Misc",
		"<Title>",
		'\0',
		"",
		N_MSG_NIN_MISC, "",
		NULL, NULL,
		FLG_NULL,
	},

	{
		"/Spell/NIN/SUBSTITUTE",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_SUBSTITUTE, "",
		cb_menu_spell, (void *)SPELL_KIND_SUBSTITUTE,
		FLG_NULL,
	},

	{
		"/Spell/NIN/BURNING_HANDS",
		"<Branch>",
		'\0',
		"",
		N_MSG_SPELL_BURNING_HANDS, "",
		cb_menu_spell, (void *)SPELL_KIND_BURNING_HANDS,
		FLG_NULL,
	},

	{
		"/Spell/NIN/NO_LEARN Misc",
		"<Item>",
		'Z',
		"",
		N_MSG_SPELL_NO_LEARN, "",
		cb_menu_spell_no_learn, NULL,
		FLG_NULL,
	},

	{
		"/Spell/NIN/--",
		"<PageSeparator>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
/*  */
	{
		"",
		"",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
};

menu_t	ls_menu_spell_extent[] = {
	{
		"/Spell Extent",
		"<Branch>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
	{
		"/Spell Extent/Normal",
		"<Item>",
		'N',
		"",
		N_MSG_SPELL_EXTENT_NORMAL, "",
		cb_menu_spell_extent, (void *)EXTENT_KIND_NORMAL,
		FLG_NULL,
	},
	{
		"/Spell Extent/Spread",
		"<Item>",
		'S',
		"",
		N_MSG_SPELL_EXTENT_SPREAD, "",
		cb_menu_spell_extent, (void *)EXTENT_KIND_SPREAD,
		FLG_NULL,
	},
	{
		"/Spell Extent/Mass",
		"<Item>",
		'M',
		"",
		N_MSG_SPELL_EXTENT_MASS, "",
		cb_menu_spell_extent, (void *)EXTENT_KIND_MASS,
		FLG_NULL,
	},
	{
		"/Spell Extent/Half",
		"<Item>",
		'H',
		"",
		N_MSG_SPELL_EXTENT_HALF, "",
		cb_menu_spell_extent, (void *)EXTENT_KIND_HALF,
		FLG_NULL,
	},
	{
		"",
		"",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
};

/******************************************************************/

#if	0
typedef struct {
	spell_kind_t	kind;
	n_msg_t	n_name;
	char	*name;
	long	hp, mp;
	gold_t	gold;
	abl_kind_t	abl;
	flg_extent_t	flg_extent;
	bool_t	flg_trgt;
	resi_kind_t	resi;
	gold_t	price;
} spell_tab_t;
#endif

spell_tab_t	spell_tab[] = {
	{
		SPELL_KIND_NULL,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_HP, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},
/* MAG */
	{
		SPELL_KIND_MAG_MIN_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_MAG, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},

	{
		SPELL_KIND_LIGHT,
		N_MSG_SPELL_LIGHT, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_ELEC,
		((gold_t)100),
	},

	{
		SPELL_KIND_DARKNESS,
		N_MSG_SPELL_DARKNESS, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_POIS,
		((gold_t)100),
	},

	{
		SPELL_KIND_TELEPORT_PARTY,
		N_MSG_SPELL_TELEPORT_PARTY, "",
		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_TELEPORT,
		N_MSG_SPELL_TELEPORT, "",
		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_RECALL,
		N_MSG_SPELL_RECALL, "",
		0, 10, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_KNOCK,
		N_MSG_SPELL_KNOCK, "",
		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_LOCK,
		N_MSG_SPELL_LOCK, "",
		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DISARM_TRAP,
		N_MSG_SPELL_DISARM_TRAP, "",
		0, 2, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DISPEL_MAGIC,
		N_MSG_SPELL_DISPEL_MAGIC, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_MIRROR_IMAGE,
		N_MSG_SPELL_MIRROR_IMAGE, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_ANIMATE_OBJECTS,
		N_MSG_SPELL_ANIMATE_OBJECTS, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SHELTER,
		N_MSG_SPELL_SHELTER, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CREATE_FOOD,
		N_MSG_SPELL_CREATE_FOOD, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CREATE_UNDEAD,
		N_MSG_SPELL_CREATE_UNDEAD, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_IDENTIFY_ITEM,
		N_MSG_SPELL_IDENTIFY_ITEM, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SEARCHING,
		N_MSG_SPELL_SEARCHING, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_ANALYZE_DWEOMER,
		N_MSG_SPELL_ANALYZE_DWEOMER, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DETECT_MAGIC,
		N_MSG_SPELL_DETECT_MAGIC, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DETECT_ITEM,
		N_MSG_SPELL_DETECT_ITEM, "",
		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DETECT_DOORS,
		N_MSG_SPELL_DETECT_DOORS, "",
		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DETECT_TRAPS,
		N_MSG_SPELL_DETECT_TRAPS, "",
		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DETECT_MONSTER,
		N_MSG_SPELL_DETECT_MONSTER, "",
		0, 4, 0, ABL_KIND_MAG, FLG_EXTENT_NORMAL, FALSE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SENSE_INVISIBLE,
		N_MSG_SPELL_SENSE_INVISIBLE, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_FLY,
		N_MSG_SPELL_FLY, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_FEATHER_FALL,
		N_MSG_SPELL_FEATHER_FALL, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_VANISH,
		N_MSG_SPELL_VANISH, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DARKVISION,
		N_MSG_SPELL_DARKVISION, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_PASSWALL,
		N_MSG_SPELL_PASSWALL, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_POLYMORPH_OTHER,
		N_MSG_SPELL_POLYMORPH_OTHER, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_POLYMORPH_SELF,
		N_MSG_SPELL_POLYMORPH_SELF, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_STEALTH,
		N_MSG_SPELL_STEALTH, "",
		0, 1, 0, ABL_KIND_MAG, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_MAG_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_MAG, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},
/* SOR */
	{
		SPELL_KIND_SOR_MIN_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_SOR, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},

	{
		SPELL_KIND_MAGIC_MISSILE,
		N_MSG_SPELL_MAGIC_MISSILE, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_KNOC,
		((gold_t)100),
	},

	{
		SPELL_KIND_FIRE_BALL,
		N_MSG_SPELL_FIRE_BALL, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_HEAT,
		((gold_t)100),
	},

	{
		SPELL_KIND_ICE_BLIZZARD,
		N_MSG_SPELL_ICE_BLIZZARD, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_COLD,
		((gold_t)100),
	},

	{
		SPELL_KIND_ACID_RAIN,
		N_MSG_SPELL_ACID_RAIN, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_ACID,
		((gold_t)100),
	},

	{
		SPELL_KIND_MIND_STORM,
		N_MSG_SPELL_MIND_STORM, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_LIGHTNING_BOLT,
		N_MSG_SPELL_LIGHTNING_BOLT, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_ELEC,
		((gold_t)100),
	},

	{
		SPELL_KIND_POISON_CLOUD,
		N_MSG_SPELL_POISON_CLOUD, "",
		0, 4, 0, ABL_KIND_SOR, FLG_EXTENT_ALL, TRUE,
		RESI_KIND_POIS,
		((gold_t)100),
	},

	{
		SPELL_KIND_DEATH_SPELL,
		N_MSG_SPELL_DEATH_SPELL, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_MAGIC_SHIELD,
		N_MSG_SPELL_MAGIC_SHIELD, "",
		0, 1, 1, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_MAGE_ARMOR,
		N_MSG_SPELL_MAGE_ARMOR, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_STONESKIN,
		N_MSG_SPELL_STONESKIN, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_IRON_BODY,
		N_MSG_SPELL_IRON_BODY, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SPELL_RESISTANCE,
		N_MSG_SPELL_SPELL_RESISTANCE, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_COUNTER_MAGIC,
		N_MSG_SPELL_COUNTER_MAGIC, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_STONE,
		N_MSG_SPELL_STONE, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_PARALYZE,
		N_MSG_SPELL_PARALYZE, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_BLINDNESS,
		N_MSG_SPELL_BLINDNESS, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_POISON,
		N_MSG_SPELL_POISON, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_POIS,
		((gold_t)100),
	},

	{
		SPELL_KIND_CONFUSION,
		N_MSG_SPELL_CONFUSION, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_SILENCE,
		N_MSG_SPELL_SILENCE, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SLEEP,
		N_MSG_SPELL_SLEEP, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_FEAR,
		N_MSG_SPELL_FEAR, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_HALLUCINATION,
		N_MSG_SPELL_HALLUCINATION, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_CHARM,
		N_MSG_SPELL_CHARM, "",
		0, 1, 0, ABL_KIND_SOR, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_SOR_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_SOR, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},
/* ENC */
	{
		SPELL_KIND_ENC_MIN_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_ENC, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},

	{
		SPELL_KIND_SHARPNESS,
		N_MSG_SPELL_SHARPNESS, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_STRENGTH,
		N_MSG_SPELL_STRENGTH, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_QUICKNESS,
		N_MSG_SPELL_QUICKNESS, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_WISE,
		N_MSG_SPELL_WISE, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_BRAINY,
		N_MSG_SPELL_BRAINY, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_ATTRACTIVE,
		N_MSG_SPELL_ATTRACTIVE, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_POWER_UP_HP,
		N_MSG_SPELL_POWER_UP_HP, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_HASTE,
		N_MSG_SPELL_HASTE, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DULLNESS,
		N_MSG_SPELL_DULLNESS, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_WEAKNESS,
		N_MSG_SPELL_WEAKNESS, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SLOWNESS,
		N_MSG_SPELL_SLOWNESS, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_FOOLISH,
		N_MSG_SPELL_FOOLISH, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_BRAINLESS,
		N_MSG_SPELL_BRAINLESS, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_UNATTRACTIVE,
		N_MSG_SPELL_UNATTRACTIVE, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_ENERGY_DRAIN,
		N_MSG_SPELL_ENERGY_DRAIN, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MIND,
		((gold_t)100),
	},

	{
		SPELL_KIND_SLOW,
		N_MSG_SPELL_SLOW, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_HUNGER,
		N_MSG_SPELL_HUNGER, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CANCELLATION,
		N_MSG_SPELL_CANCELLATION, "",
		0, 1, 0, ABL_KIND_ENC, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_ENC_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_ENC, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},
/* SUM */
	{
		SPELL_KIND_SUM_MIN_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_SUM, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},

	{
		SPELL_KIND_SUMMON_MONSTER,
		N_MSG_SPELL_SUMMON_MONSTER, "",
		0, 1, 0, ABL_KIND_SUM, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_DISMISSAL,
		N_MSG_SPELL_DISMISSAL, "",
		0, 1, 0, ABL_KIND_SUM, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_SUM_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_SUM, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},
/* PRI */
	{
		SPELL_KIND_PRI_MIN_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_PRI, FLG_NULL, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)0),
	},

	{
		SPELL_KIND_CURE_HP_LIGHT,
		N_MSG_SPELL_CURE_HP_LIGHT, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_HP_MODERATE,
		N_MSG_SPELL_CURE_HP_MODERATE, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_HP_SERIOUS,
		N_MSG_SPELL_CURE_HP_SERIOUS, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_HP_MAX,
		N_MSG_SPELL_CURE_HP_MAX, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_MP,
		N_MSG_SPELL_CURE_MP, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_TRANSFER_MP,
		N_MSG_SPELL_TRANSFER_MP, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_REGENERATION,
		N_MSG_SPELL_REGENERATION, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		RESI_KIND_MAX_N,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESTORE_EXPERIENCE,
		N_MSG_SPELL_RESTORE_EXPERIENCE, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESURRECTION,
		N_MSG_SPELL_RESURRECTION, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_NORMAL, FALSE,
		((gold_t)100),
	},

	{
		SPELL_KIND_HEAL,
		N_MSG_SPELL_HEAL, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_STATUS,
		N_MSG_SPELL_CURE_STATUS, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_STONE,
		N_MSG_SPELL_CURE_STONE, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_PARALYZE,
		N_MSG_SPELL_CURE_PARALYZE, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_BLINDNESS,
		N_MSG_SPELL_CURE_BLINDNESS, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_POISON,
		N_MSG_SPELL_CURE_POISON, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_CONFUSION,
		N_MSG_SPELL_CURE_CONFUSION, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_SILENCE,
		N_MSG_SPELL_CURE_SILENCE, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_SLEEP,
		N_MSG_SPELL_CURE_SLEEP, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_FEAR,
		N_MSG_SPELL_CURE_FEAR, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CURE_CHARM,
		N_MSG_SPELL_CURE_CHARM, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_PROTECTION,
		N_MSG_SPELL_PROTECTION, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_PHYSICAL,
		N_MSG_SPELL_RESIST_PHYSICAL, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_HEAT,
		N_MSG_SPELL_RESIST_HEAT, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_COLD,
		N_MSG_SPELL_RESIST_COLD, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_ACID,
		N_MSG_SPELL_RESIST_ACID, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_MIND,
		N_MSG_SPELL_RESIST_MIND, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_ELECTRICITY,
		N_MSG_SPELL_RESIST_ELECTRICITY, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_RESIST_POISON,
		N_MSG_SPELL_RESIST_POISON, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_BLESS,
		N_MSG_SPELL_BLESS, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_REMOVE_CURSE,
		N_MSG_SPELL_REMOVE_CURSE, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_DISPEL_UNDEAD,
		N_MSG_SPELL_DISPEL_UNDEAD, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_SANCTUARY,
		N_MSG_SPELL_SANCTUARY, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_WISH,
		N_MSG_SPELL_WISH, "",
		0, 1, 0, ABL_KIND_PRI, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_PRI_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_PRI, FLG_NULL, TRUE,
		((gold_t)0),
	},
/* SHA */





/* BAR */





/* NIN */
	{
		SPELL_KIND_NIN_MIN_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_NIN, FLG_NULL, TRUE,
		((gold_t)0),
	},

	{
		SPELL_KIND_TYPHOON,
		N_MSG_SPELL_TYPHOON, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_CONFLAGRATION,
		N_MSG_SPELL_CONFLAGRATION, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_EARTHQUAKE,
		N_MSG_SPELL_EARTHQUAKE, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_THUNDERCLOUD,
		N_MSG_SPELL_THUNDERCLOUD, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_INUNDATION,
		N_MSG_SPELL_INUNDATION, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_MASS, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_SUBSTITUTE,
		N_MSG_SPELL_SUBSTITUTE, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_BURNING_HANDS,
		N_MSG_SPELL_BURNING_HANDS, "",
		1, 0, 0, ABL_KIND_NIN, FLG_EXTENT_STD, TRUE,
		((gold_t)100),
	},

	{
		SPELL_KIND_NIN_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_NIN, FLG_NULL, TRUE,
		((gold_t)0),
	},
/* end */
	{
		SPELL_KIND_MAX_N,
		N_MSG_NULL, "",
		0, 0, 0, ABL_KIND_HP, FLG_NULL, TRUE,
		((gold_t)0),
	},
};

#endif	/* SPELL_TAB_H */
